@@ -514,6 +514,35 @@ def post_chunk(ctx: MemfaultCliClickContext, encoding, data, **kwargs):
     _do_post_chunks_or_raise(ctx, chunks)
 
 
+@cli.command("completion")
+@click.option(
+    "--shell",
+    type=click.Choice(["bash", "zsh", "fish"]),
+    required=True,
+    help="select shell type for completion script",
+)
+@click.pass_context
+def completion(ctx, shell: str):
+    """
+    Generate shell completion script for memfault.
+
+    \b
+    Example:
+    \b
+        $ memfault completion --shell bash > ~/.memfault_completion.bash
+        $ echo 'source ~/.memfault_completion.bash' >> ~/.bashrc
+
+    """
+
+    # re-invoke the main cli entrance point after setting the Click completion
+    # environment variable. it's necessary to do this via the Click ctx so that
+    # it works properly when invoked from pytest or normal cli usage.
+
+    cmd = "memfault"
+    os.environ[f"_{cmd.upper()}_COMPLETE"] = f"{shell}_source"
+    ctx.command.main(prog_name="memfault")
+
+
 def main():
     logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
     cli(auto_envvar_prefix="MEMFAULT")
