@@ -30,7 +30,7 @@ LOG = logging.getLogger(__name__)
 GNU_BUILD_ID_RE = re.compile(r"Build ID: (?P<gnu_build_id>[a-f\d]+)")
 
 
-def hash_io_hexdigest(name, data: IO, chunksize=2 ** 20) -> str:
+def hash_io_hexdigest(name, data: IO, chunksize=2**20) -> str:
     """
     A wrapper around hashlib.new() and hexdigest() which reads
     from a stream in chunks
@@ -92,8 +92,9 @@ class Uploader(metaclass=abc.ABCMeta):
     def _api_base_url(self) -> str:
         return f"{self.base_url}/api/v0"
 
-    def _projects_base_url(self) -> str:
-        return f"{self.base_url}/api/v0/organizations/{self.ctx.org}/projects/{self.ctx.project}"
+    def _projects_base_url(self, *, base_url_override=None) -> str:
+        base_url = base_url_override if base_url_override is not None else self.base_url
+        return f"{base_url}/api/v0/organizations/{self.ctx.org}/projects/{self.ctx.project}"
 
     def _projects_ui_base_url(self) -> str:
         return f"{self.app_url}/organizations/{self.ctx.org}/projects/{self.ctx.project}"
@@ -166,6 +167,15 @@ class Uploader(metaclass=abc.ABCMeta):
 
         check_response(response)
 
+    @property
+    def qcomm_project(self):
+        response = self.session.get(
+            self._projects_base_url(base_url_override=self.ctx.api_url),
+            **self.authenticator.requests_auth_params(),
+        )
+        check_response(response)
+        return response.json()["data"].get("qcomm_enabled", False)
+
     def upload(self, *, progressbar=True) -> bool:
         if self._is_already_uploaded():
             LOG.info("%s: skipping, already uploaded.", self.file_path)
@@ -243,7 +253,7 @@ class XedUploader(Uploader):
 class MarUploader(Uploader):
     def can_upload_file(self) -> bool:
         if not is_zipfile(self.file_path):
-            LOG.error(f"{self.file_path} is not a valid zip file!")
+            LOG.error("%s is not a valid zip file!", self.file_path)
             return False
         return True
 
@@ -287,6 +297,7 @@ class AospSymbolUploader(Uploader):
         if not gnu_build_id:
             LOG.info("%s: looks like an ELF but does not contain a GNU Build ID", self.file_path)
             return False
+
         self.gnu_build_id = gnu_build_id
         if not has_debug_info:
             LOG.info("%s: looks like an ELF but it has no .debug_info", self.file_path)
@@ -328,7 +339,9 @@ class McuSdkElfSymbolUploader(Uploader):
 
             mcu_build_id_type, mcu_build_id, mcu_build_id_short_len = inspector.get_build_info()
 
-            if not self.ctx.software_info and mcu_build_id is None:
+            # NB: QC symbol files have different arg requirements depending on the subsystem the
+            # ELF is associated with so we offload to the Memfault backend.
+            if not self.ctx.software_info and mcu_build_id is None and not self.qcomm_project:
                 LOG.error(
                     "%s: Build Id missing. Specify --software-version and --software-type options "
                     "or add a Build Id (see https://mflt.io/symbol-file-build-ids)",
@@ -431,8 +444,8 @@ class DirectoryUploader(Uploader):
     def can_upload_file(self) -> bool:
         return os.path.isdir(self.file_path)
 
-    def _walk_files(self, root: str) -> Generator[str, Any, Any]:
-        for root, _dirs, files in os.walk(root):
+    def _walk_files(self, toplevel: str) -> Generator[str, Any, Any]:
+        for root, _dirs, files in os.walk(toplevel):
             yield from map(lambda file: os.path.join(root, file), files)
 
     def upload(self, *, progressbar=True) -> bool:
